/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-09-04 15:07:56
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-10-14 16:50:35
 * @FilePath: \Game-Backstage-Management-System\src\hooks\useForm.ts
 * @Description:
 *
 */
import type { FormInstance } from 'element-plus'

import { ElMessage, ElMessageBox } from 'element-plus'
import { nextTick } from 'vue'
import { useRequest } from './useRequest'

import axiosInstance from '@/utils/axios/axiosInstance'

const { analysisResCode } = useRequest()
export function useForm() {
  const validForm = async (formEl: FormInstance | undefined): Promise<boolean> => {
    if (!formEl) {
      console.log('找不到表单实例')
      return false
    }
    return await formEl.validate()
  }

  // 对话框提交
  const submitForm = (formEl: FormInstance | undefined, url: string, formData: any) => {
    return new Promise((resolve, reject) => {
      ElMessageBox.confirm('确认提交吗？', '警告', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning',
        appendTo: 'body'
      })
        .then(async () => {
          try {
            const valid = await validForm(formEl)
            if (!valid) {
              console.log('表单校验不通过')
              reject(false)
              return
            }

            const result = await axiosInstance.post(url, formData)
            const info = JSON.parse(JSON.stringify(result))

            await analysisResCode(info)
            resolve(true)
          } catch (err) {
            console.log(err)
            ElMessage({
              type: 'error',
              message: '表单验证不通过'
            })
            reject(false)
          }
        })
        .catch(() => {
          console.log('取消选择')
          reject(false)
        })
    })
  }

  // 修改按钮
  const editForm = (row: any, formData: any) => {
    // 这里放到nextTick，因为resetFields原理是将表单重置到dom刚渲染时的数据
    // 而这个表单，如果第一次使用就点击编辑的话，会将初始值直接设置为这行的数据，导致无法重置
    void nextTick(() => {
      for (const key in row) {
        if (key in formData) {
          formData[key] = row[key]
        } else {
          console.log(key)
        }
      }
    })
  }

  return { submitForm, editForm, validForm: validForm }
}
