enum CustomFilterValueType {
  INPUT,
  DATEPICKER,
  SELECT
}

interface BaseCustomFilter {
  valueType: CustomFilterValueType
}

interface InputCustomFilter extends BaseCustomFilter {
  valueType: CustomFilterValueType.INPUT
  valueFormat?: (...args: any[]) => any
  valueValid?: (val: any) => boolean
}

interface DatePickerCustomFilter extends BaseCustomFilter {
  valueType: CustomFilterValueType.DATEPICKER
  format: string
  valueFormat: string
}

interface SelectCustomFilter extends BaseCustomFilter {
  valueType: CustomFilterValueType.SELECT
  defaultDate: Date
  options: Array<{
    label: string
    value: string
  }>
}

interface FilterItem {
  filterCondition: string
  value: any
}

type CustomFilter = InputCustomFilter | DatePickerCustomFilter | SelectCustomFilter

export { CustomFilterValueType }

export type {
  CustomFilter,
  InputCustomFilter,
  DatePickerCustomFilter,
  SelectCustomFilter,
  FilterItem
}
