/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-23 14:58:29
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-11-29
 * @FilePath: \Game-Backstage-Management-System\src\types\dataAnalysis.ts
 * @Description:用于dataAnalysis相关组件的type
 *
 */

// 下拉选项的信息
export interface DropDownItem {
  value: any
  label: string
}

// 下拉框所需要的props信息
export interface DropDownInfo {
  size?: string
  defaultSelect: any
  title: string
  optionsList: Array<DropDownItem>
}

/**
 * @description: 数据展示组件的请求配置
 *
 * @return {*}
 */
export interface ReqConfig {
  url: string
  otherOptions: {
    [key: string]: any
  }
}

// 数据展示的字段信息
export interface StaticField {
  name: string
  cnName: string
  value: any // 值
  compareVal?: any
}

// 数据分析页面头部数据所需要的props
// 其中如果配置了请求参数，那么会使用url去查询，然后赋值
// 如果没有则直接使用fieldInfo里的value
export interface StaticDataInfo {
  requestConfig?: ReqConfig // 请求参数配置
  fieldsInfo: Array<StaticField> //字段信息
  titleClass?: string // 标题的样式
  valueClass?: string // 值的样式
}

// 时间趋势图的tab信息
export interface TabInfo {
  name: string // tab的字段
  tabTitle: string // tab的标题
  type: number // 请求参数中，需要的字段，用来区分不同的请求
}

/**
 * @description: 图表所需要的props,其中的leanedData毓seriesData的length要一致
 *              series中的name依赖毓leanedData
 * @return {*}
 */
export interface OptionsProps {
  xAxisData: Array<any> // x轴的刻度label
  legendData: Array<any> // 图例的信息
  seriesData: Array<any> // 数据
}

// 返回的数据中每个字段的分类信息
export interface ResDataFieldInfo {
  xAxis: string // x轴的刻度信息所在的字段
  values: Array<string> // 值所在的字段
}

// 表格字段
// key需要与上方的resDataField的values字段对应
export interface TrendTableField {
  [key: string]: {
    [key: string]: any
  }
}

// 时间趋势组件所需要的props
export interface TemporalTrendProps {
  needDownload?: boolean // 是否需要下载

  tabInfo?: Array<TabInfo> // 用于切换的tab的信息

  type?: number // 趋势组件的类型，1为小时段，2为日期统计
  needChangeExpress?: boolean // 是否需要切换表格/图表
  selectExpressForm?: number // 默认的表现形式，1为图表，2为表格

  needTable?: boolean // 是否需要表格
  tableFieldsInfo: TrendTableField // 表格的字段信息，必填，因为legend的字段也依赖这里

  needCharts?: boolean // 是否需要图表

  resDataFieldsInfo: ResDataFieldInfo // 返回的数据中每个字段的分类信息
  requestConfig: ReqConfig // 请求参数配置，需要监听，一旦变化，需要重新获取数据

  staticFields?: { [key: string]: Array<StaticField> } // 图表中统计组件的字段信息
  // staticFields?: Array<StaticField> // 图表中统计组件的字段信息
  title: string // 上方显示的title
}

// 头部切换组件所需要的props
export interface HeaderCardProps {
  title: string // title信息
  openDateSelect?: boolean // 是否开启时间选择
  needPfSelect?: boolean // 是否需要平台选择
  needBreadcrumb?: boolean // 是否需要面包屑导航
  isRadio?: boolean // 是否为单选
}

// 趋势图组件需要的信息
export interface TemporalTrendInfo {
  dataReqConfig: ReqConfig // 请求的参数和配置
  resDataField: ResDataFieldInfo // 返回数据中的字段信息
  tabList?: Array<TabInfo> //标签页数据
  trendTableFields: TrendTableField // 表格的字段，同时也作为legend的一部分
  // chartsStaticField?: Array<StaticField> // 统计字段的信息
  chartsStaticField?: { [key: string]: Array<StaticField> } // 统计字段的信息
}

export interface IconDropdownItem {
  value: string
  icon: string
  label: string
  isSelected: boolean
}
