// 字段特殊效果类型
enum FieldSpecialEffectType {
  TEXT = 'text',
  SWITCH = 'switch',
  DROPDOWN = 'dropdown',
  IMG = 'img',
  CUSTOM = 'custom'
}

// 文本类型字段类型
enum TextType {
  TEXT = 'text', // 普通文字
  LINK = 'link', // 链接
  DATE = 'date', // 日期
  INT = 'int', // 整数,
  FLOAT = 'float', // 浮点数
  PERCENT = 'percent', // 百分比
  TAG = 'tag' // 标签
}

// 标签类型
enum TagType {
  PRIMARY = 'primary',
  SUCCESS = 'success',
  INFO = 'info',
  WARNING = 'warning',
  DANGER = 'danger'
}

// 定义每种 specialEffect 结构
interface SpecialEffectText {
  type: FieldSpecialEffectType.TEXT
  otherInfo: {
    // 颜色
    color?:
      | string[]
      | {
          [key: string]: string
        }
      | string
    // 翻译字典，即需要对应的值进行翻译，根据值不同展示不同文字
    translateMap?:
      | {
          [key: string | number]: string
        }
      | Array<string>
    disabledTextColor?: boolean // 是否禁用文字颜色，默认不禁用，当启用了前缀图标时默认禁用
    needPreIcon?: boolean // 是否需要前缀图标
    tagType?: TagType[] // 标签类型
    textType: TextType // 文本类型
  }
}

// 开关类型的特殊效果
interface SpecialEffectSwitch {
  type: FieldSpecialEffectType.SWITCH
  otherInfo: {}
}

// 下拉框类型的特殊效果
interface SpecialEffectDropdown {
  type: FieldSpecialEffectType.DROPDOWN
  otherInfo: {}
}

// 图片类型的特殊效果
interface SpecialEffectImg {
  type: FieldSpecialEffectType.IMG
  otherInfo: {}
}

// 自定义类型
interface SpecialEffectCustom {
  type: FieldSpecialEffectType.CUSTOM
  otherInfo: {
    // 自定义渲染函数
    render: (value: any) => any
  }
}

// 所有特殊效果类型
type SpecialEffect =
  | SpecialEffectText
  | SpecialEffectSwitch
  | SpecialEffectDropdown
  | SpecialEffectImg
  | SpecialEffectCustom

export { FieldSpecialEffectType, TextType, TagType }

export type { SpecialEffect }

export type {
  SpecialEffectText,
  SpecialEffectSwitch,
  SpecialEffectDropdown,
  SpecialEffectImg,
  SpecialEffectCustom
}
