import { useTableStore } from '@/stores/useTable'
import { useRequest } from '@/hooks/useRequest'

import axiosInstance from '../axios/axiosInstance'
import type { ResponseInfo } from '@/types/res.ts'

const { AllApi } = useRequest()

/**
 * 格式化游戏信息
 * @param {Array} data 获取到的表格数据
 * @param {number} code 状态码
 */
const formatGameInfo = (data: Array<any>, code: number): Array<any> => {
  const returnData: Array<any> = []

  if (code === 0 && Array.isArray(data)) {
    const gameInfoList = data.map((item) => {
      return { gid: item.gid, gameName: item.gameName }
    })
    returnData.splice(0, returnData.length, ...gameInfoList)
  } else {
    console.log('获取游戏列表失败')
  }
  return returnData
}

/**
 * 获取所有游戏信息
 */
export const getAllGameInfo = async () => {
  try {
    const tableStore = useTableStore() // 这一句不要直接写在函数外面，会导致在pinia挂载之前被调用

    // 如果已经有了，那么直接用缓存
    if (tableStore.allGameInfo.length) return tableStore.allGameInfo

    const response = (await axiosInstance.post(AllApi.getGameTable, {
      appSecret: '6YJSuc50uJ18zj45'
    })) as ResponseInfo
    if (!response || response.code !== 0) {
      console.log('获取游戏列表失败')
      return []
    }
    const result = JSON.parse(JSON.stringify(response))
    const data = result.data
    const returnData: Array<any> = formatGameInfo(data, result.code)
    tableStore.setGameInfo(returnData) // 格式化后的数据放到tableStore中

    return returnData
  } catch (err) {
    console.log(err)
    return []
    // throw new Error('获取游戏列表失败')
  }
}

/**
 * 根据路由的name判断这个组件是否需要监听事件
 * @param routeName 当前路由name
 * @param matchName 匹配的路由name
 */
export const shouldListenToEvent = (routeName: string | symbol | undefined, matchName: string) => {
  return routeName === matchName
}

/**
 * 下载文件信息
 * @param {string} fileName 指定文件名
 * @param {any} info  需要下载的信息
 */
export const downLoadData = (fileName: string, info: any) => {
  const result = {
    ...info
  }
  const blob = new Blob([JSON.stringify(result)], { type: 'application/json' })
  const url = URL.createObjectURL(blob)
  const a = document.createElement('a')
  a.href = url
  a.download = fileName
  a.click()
  URL.revokeObjectURL(url)
}
