import { useRequest } from '@/hooks/useRequest'

import axios from 'axios'

const { AllApi, baseURL } = useRequest()

const TokenKey = 'token' // token的key
const RefreshTokenKey = 'refreshToken' // 刷新token的key

/**
 * 获取token
 */
const getToken = () => {
  return localStorage.getItem(TokenKey)
}

/**
 *  设置token
 * @param {string} token token
 */
const setToken = (token: string) => {
  localStorage.setItem(TokenKey, token)
}

/**
 *  获取刷新Token
 */
const getRefreshToken = () => {
  return localStorage.getItem(RefreshTokenKey)
}

/**
 * 设置刷新Token
 * @param {string} refreshToken 刷新token
 */
const setRefreshToken = (refreshToken: string) => {
  localStorage.setItem(RefreshTokenKey, refreshToken)
}

/**
 * 刷新Token
 */
const refreshToken = async () => {
  // 这里不要用实例去请求，如果refreshToken也返回-1的话，会导致程序卡死
  return await axios.post(
    `${baseURL}${AllApi.getRefreshToken}`,
    {},
    {
      headers: {
        Authorization: `${getRefreshToken()}`
      }
    }
  )
}

/**
 *  移除token
 */
const removeToken = () => {
  localStorage.removeItem(TokenKey)
}

/**
 * 移除refreshToken
 *
 */
const removeRefreshToken = () => {
  localStorage.removeItem(RefreshTokenKey)
}

/**
 *  移除所有token
 */
const removeAllToken = () => {
  removeToken()
  removeRefreshToken()
}

export {
  getToken,
  setToken,
  getRefreshToken,
  setRefreshToken,
  refreshToken,
  removeToken,
  removeRefreshToken,
  removeAllToken
}
